@@ -279,6 +279,7 @@ class DeltaTable:
         header = kw.get('header') or 'true'
         multiline = kw.get('multiLine') or 'true'
         escape = kw.get('escape') or "\""
+        bad_records_path = kw.get('badRecordsPath') or f"/tmp/{self.schema_name}/{self.table_name}/bad_records"
 
         if format == 'csv':
             df = spark.readStream.format('cloudFiles') \
@@ -295,6 +296,7 @@ class DeltaTable:
                 .option('cloudFiles.format', format) \
                 .option('header', header) \
                 .option("cloudFiles.schemaLocation", self.checkpoint_path) \
+                .option('badRecordsPath', bad_records_path) \
                 .load(self.upload_path)
         return df
 
